@@ -19,7 +19,6 @@ use OP::Class qw| true false |;
 use base qw| OP::Class::Dumper OP::Object |;
 
 use Error qw| :try |;
-use Hash::Util;
 
 =pod
 
@@ -326,10 +325,6 @@ sub isEmpty {
 
 This file is part of L<OP>.
 
-=head1 REVISION
-
-$Id: //depotit/tools/source/snitchd-0.20/lib/OP/Hash.pm#13 $
-
 =cut
 
 1;
